from setuptools import setup


setup(
    name='wombopy',
    version='0.1.0',
    description='A module to generate wombo.art images',
    author='Holy Tanuki',
    packages=['wombopy'],
    install_requires=[
        "typer==0.4.0",
        "colorama==0.4.4",
        "shellingham==1.4.0",
        "pytest==7.0.1",
        "requests==2.27.1",
    ],
    python_requires=">=3.9",
)
